@@ -1,9 +1,10 @@
 #!/usr/bin/perl
 
 #
-# $Id: perlcritic-checker.pl 70 2011-02-28 10:17:47Z xdr.box $
+# $Id: perlcritic-checker.pl 5 2010-06-06 10:00:34Z xdr.box $
 #
-# Perl::Critic Subversion Hook
+# Subversion pre-commit hook script for checking
+# Perl-code using Perl::Critic module
 #
 # Copyright (C) 2009-2010 Alexander Simakov, <xdr (dot) box (at) Google Mail>
 # http://alexander-simakov.blogspot.com/
@@ -30,7 +31,7 @@
 use strict;
 use warnings;
 
-our $VERSION = '1.2.6';
+our $VERSION = '1.2';
 
 use Readonly;
 use English qw(-no_match_vars);
@@ -266,10 +267,9 @@ sub get_profile_for {
     my $profiles = $Config->{'profiles'};
 
     my $last_match = last_value { $file =~ $_->{'pattern'} } @{$profiles};
-    return if !defined $last_match;    # no match at all
+    return if !defined $last_match;
 
     my $profile = $last_match->{'profile'};
-    return if !defined $profile;    # file is explicitly marked to be ignored
 
     if ( !file_name_is_absolute($profile) ) {
         ### relative profile path: $profile
@@ -678,7 +678,7 @@ __END__
 
 =head1 NAME
 
-perlcritic-checker.pl - Perl::Critic Subversion Hook
+perlcritic-checker.pl - Tool for automating code quality control
 
 =head1 SYNOPSIS
 
@@ -701,27 +701,10 @@ Put this into your Subversion's pre-commit hook:
 
 =head1 DESCRIPTION
 
-perlcritic-checker is a subversion hook that allows commits to go through
-if and only if the code passes validation using Perl::Critic module.
-This way you can apply consistent coding practices inside your team.
-
-Main features:
-
-=over 4
-
-=item * you can specify different Perl::Critic's profiles for different
-paths in your repository
-
-=item * you can bypass checks when you do need this
-
-=item * you can apply the checker to your existing large legacy Perl
-project by using "progressive mode" feature: in progressive mode
-perlcritic-checker doesn't complain about existing violations but prevents
-introducing new ones
-
-=item * perlcritic-checker comes with a test suite
-
-=back
+This script checks Perl code using Perl::Critic module.
+It is assumed that it will be invoked from Subversion's
+pre-commit hook. This way you can fine tune and automate
+code quality control.
 
 =head1 CONFIGURATION FILE
 
