@@ -1,17 +1,15 @@
 #!/usr/bin/perl
 
 #===============================================================================
-#     REVISION:  $Id: test1-5.pl 2 2010-06-04 13:42:47Z xdr.box $
-#  DESCRIPTION:  This file differs from test1-4.pl only in this line
+#     REVISION:  $Id: test5-1.pl 2 2010-06-04 13:42:47Z xdr.box $
+#  DESCRIPTION:  no violations
 #===============================================================================
 
-#use strict;
+use strict;
 use warnings;
 
 our $VERSION = '1.0';
 
-sub { print $_[0] }
-
 sub main {
     return;
 }
